@@ -27,13 +27,14 @@ from AnyQt.QtGui import (
 from AnyQt.QtCore import (
     Qt, QEvent, QPointF, QRectF, QRect, QSize, QTime, QTimer,
     QPropertyAnimation, QEasingCurve, QObject, QVariantAnimation,
-    QParallelAnimationGroup)
+    QParallelAnimationGroup, Slot)
 from AnyQt.QtCore import pyqtSignal as Signal, pyqtProperty as Property
 from PyQt5.QtCore import pyqtProperty
 
 from .graphicspathobject import GraphicsPathObject
-from .graphicstextitem import GraphicsTextItem
+from .graphicstextitem import GraphicsTextItem, GraphicsTextEdit
 from .utils import saturated, radial_gradient
+from ...gui.utils import disconnected
 
 from ...scheme.node import UserMessage
 from ...registry import NAMED_COLORS, WidgetDescription, CategoryDescription, \
@@ -435,15 +436,19 @@ class AnchorPoint(QGraphicsObject):
     #: Signal emitted when anchor's Input/Output channel changes.
     signalChanged = Signal(QGraphicsObject)
 
-    def __init__(self, parent=None, signal=None, **kwargs):
-        # type: (Optional[QGraphicsItem], Any) -> None
+    def __init__(
+            self,
+            parent: Optional[QGraphicsItem] = None,
+            signal: Union[InputSignal, OutputSignal, None] = None,
+            **kwargs
+    ) -> None:
         super().__init__(parent, **kwargs)
         self.setFlag(QGraphicsItem.ItemIsFocusable)
         self.setFlag(QGraphicsItem.ItemSendsScenePositionChanges, True)
         self.setFlag(QGraphicsItem.ItemHasNoContents, True)
         self.indicator = LinkAnchorIndicator(self)
 
-        self.signal = signal  # type: Optional[Union[InputSignal, OutputSignal]]
+        self.signal = signal
         self.__direction = QPointF()
 
         self.anim = QPropertyAnimation(self, b'pos', self)
@@ -557,9 +562,10 @@ def matchDashPattern(l1, l2, spaceLen=2):
         return (l2, l1) if reverse else (l1, l2)
 
     elif l1d % 2 != 0 and l2d % 2 == 0:  # split line
-        l11 = l1[:l1d - 1]
-        l1m = l1[l1d]
-        l12 = l1[l1d+2:]
+        l11 = l1[:l1d - 2]
+        mid = l1[l1d-1]
+        l1m = [mid/2, 0, mid/2]
+        l12 = l1[l1d+1:]
 
         l21 = l2[:l2d-3]
         l2m = l2[l2d-2:l2d+1]
@@ -685,7 +691,7 @@ class NodeAnchorItem(GraphicsPathObject):
 
             text = s.name
             lbl.setHtml('<div align="' + ('left' if alignLeft else 'right') +
-                        '" style="font-size: small; background-color: white;" >{0}</div>'
+                        '" style="font-size: small; background-color: palette(base);" >{0}</div>'
                         .format(text))
 
             cperc = self.__getChannelPercent(s)
@@ -1350,7 +1356,11 @@ class NodeItem(QGraphicsWidget):
         self.outputAnchorItem.hide()
 
         # Title caption item
-        self.captionTextItem = GraphicsTextItem(self)
+        self.captionTextItem = GraphicsTextEdit(
+            self, editTriggers=GraphicsTextEdit.NoEditTriggers,
+            returnKeyEndsEditing=True,
+        )
+        self.captionTextItem.setTabChangesFocus(True)
         self.captionTextItem.setPlainText("")
         self.captionTextItem.setPos(0, 33)
 
@@ -1463,7 +1473,10 @@ class NodeItem(QGraphicsWidget):
         """
         if self.__title != title:
             self.__title = title
-            self.__updateTitleText()
+            if self.captionTextItem.isEditing():
+                self.captionTextItem.setPlainText(title)
+            else:
+                self.__updateTitleText()
 
     def title(self):
         # type: () -> str
@@ -1475,6 +1488,62 @@ class NodeItem(QGraphicsWidget):
     title_ = Property(str, fget=title, fset=setTitle,
                       doc="Node title text.")
 
+    #: Title editing has started
+    titleEditingStarted = Signal()
+    #: Title editing has finished
+    titleEditingFinished = Signal()
+
+    def editTitle(self):
+        """
+        Start the inline title text edit process.
+        """
+        if self.captionTextItem.isEditing():
+            return
+        self.captionTextItem.setPlainText(self.__title)
+        self.captionTextItem.selectAll()
+        self.captionTextItem.setAlignment(Qt.AlignCenter)
+        self.captionTextItem.document().clearUndoRedoStacks()
+        self.captionTextItem.editingFinished.connect(self.__editTitleFinish)
+        self.captionTextItem.edit()
+        doc = self.captionTextItem.document()
+        doc.documentLayout().documentSizeChanged.connect(
+            self.__autoLayoutTitleText, Qt.UniqueConnection
+        )
+        self.titleEditingStarted.emit()
+
+    def __editTitleFinish(self):
+        # called when title editing has finished
+        self.captionTextItem.editingFinished.disconnect(self.__editTitleFinish)
+        doc = self.captionTextItem.document()
+        doc.documentLayout().documentSizeChanged.disconnect(
+            self.__autoLayoutTitleText
+        )
+        name = self.captionTextItem.toPlainText()
+        if name != self.__title:
+            self.setTitle(name)
+        self.__updateTitleText()
+        self.titleEditingFinished.emit()
+
+    @Slot()
+    def __autoLayoutTitleText(self):
+        # auto layout the title during editing
+        doc = self.captionTextItem.document()
+        doc_copy = doc.clone()
+        doc_copy.adjustSize()
+        width = doc_copy.textWidth()
+        doc_copy.deleteLater()
+        if width == doc.textWidth():
+            return
+        self.prepareGeometryChange()
+        self.__boundingRect = None
+        with disconnected(
+                doc.documentLayout().documentSizeChanged,
+                self.__autoLayoutTitleText
+        ):
+            doc.adjustSize()
+        width = self.captionTextItem.textWidth()
+        self.captionTextItem.setPos(-width / 2.0, 33)
+
     def setAnimationEnabled(self, enabled):
         # type: (bool) -> None
         """
@@ -1677,6 +1746,8 @@ class NodeItem(QGraphicsWidget):
         """
         Update the title text item.
         """
+        if self.captionTextItem.isEditing():
+            return
         text = ['<div align="center">%s' % escape(self.title())]
 
         status_text = []
