@@ -7,7 +7,7 @@ An Dialog to edit links between two nodes in the scheme.
 
 """
 import typing
-from typing import List, Tuple, Optional, Any
+from typing import cast, List, Tuple, Optional, Any, Union
 
 from collections import namedtuple
 from xml.sax.saxutils import escape
@@ -587,6 +587,8 @@ class EditLinksNode(QGraphicsWidget):
         self.layout().setAlignment(self.__channelLayout,
                                    Qt.AlignVCenter | channel_alignemnt)
 
+        self.node: Optional[SchemeNode] = None
+        self.channels: Union[List[InputSignal], List[OutputSignal]] = []
         if node is not None:
             self.setSchemeNode(node)
 
@@ -622,13 +624,14 @@ class EditLinksNode(QGraphicsWidget):
         return QIcon(self.__icon)
 
     def setSchemeNode(self, node):
+        # type: (SchemeNode) -> None
         """
         Set an instance of `SchemeNode`. The widget will be initialized
         with its icon and channels.
 
         """
         self.node = node
-
+        channels: Union[List[InputSignal], List[OutputSignal]]
         if self.__direction == Qt.LeftToRight:
             channels = node.output_channels()
         else:
@@ -659,8 +662,8 @@ class EditLinksNode(QGraphicsWidget):
 
         self.channelAnchors = []
         grid = self.__channelLayout
-
         for i, channel in enumerate(channels):
+            channel = cast(Union[InputSignal, OutputSignal], channel)
             text = label_template.format(align=align,
                                          name=escape(channel.label))
 
@@ -668,7 +671,7 @@ class EditLinksNode(QGraphicsWidget):
             text_item.setHtml(text)
             text_item.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
             text_item.setToolTip(
-                escape(getattr(channel, 'description', type_str(channel.type)))
+                escape(getattr(channel, 'description', type_str(channel.types)))
             )
 
             grid.addItem(text_item, i, label_row,
