@@ -472,11 +472,11 @@ class NewLinkAction(UserInteraction):
                 anchor = self.current_target_item.inputAnchorItem
             else:
                 anchor = self.current_target_item.outputAnchorItem
-            if not self.showing_incompatible_widget:
-                self.remove_tmp_anchor()
-                self.showing_incompatible_widget = True
-            else:
+            if self.showing_incompatible_widget:
                 anchor.setIncompatible(False)
+                self.showing_incompatible_widget = False
+            else:
+                self.remove_tmp_anchor()
             anchor.setHovered(False)
             anchor.setCompatibleSignals(None)
             self.current_target_item = None
@@ -605,8 +605,12 @@ class NewLinkAction(UserInteraction):
         from_signal = self.from_signal
         from_desc = node.description
 
-        def is_compatible(source_signal, source, sink, sink_signal):
-            # type: (WidgetDescription, WidgetDescription) -> bool
+        def is_compatible(
+                source_signal: OutputSignal,
+                source: WidgetDescription,
+                sink: WidgetDescription,
+                sink_signal: InputSignal
+        ) -> bool:
             return any(scheme.compatible_channels(output, input)
                        for output
                        in ([source_signal] if source_signal else source.outputs)
@@ -658,15 +662,19 @@ class NewLinkAction(UserInteraction):
         else:
             return None
 
-    def connect_nodes(self, source_node, sink_node,
-                            source_signal=None, sink_signal=None):
-        # type: (Node, Node) -> None
+    def connect_nodes(
+            self, source_node: Node, sink_node: Node,
+            source_signal: Optional[OutputSignal] = None,
+            sink_signal: Optional[InputSignal] = None
+    ) -> None:
         """
         Connect `source_node` to `sink_node`. If there are more then one
         equally weighted and non conflicting links possible present a
         detailed dialog for link editing.
 
         """
+        UsageStatistics.set_sink_anchor_open(sink_signal is not None)
+        UsageStatistics.set_source_anchor_open(source_signal is not None)
         try:
             possible = self.scheme.propose_links(source_node, sink_node,
                                                  source_signal, sink_signal)
@@ -1474,7 +1482,7 @@ class NewTextAnnotation(UserInteraction):
             assert self.control is not None
             assert self.annotation is not None
             # Commit the annotation to the scheme.
-            self.annotation.rect = rect_to_tuple(rect)  # type: ignore
+            self.annotation.rect = rect_to_tuple(rect)
 
             self.document.addAnnotation(self.annotation)
 
